@@ -9,6 +9,7 @@
 #include <DGuiApplicationHelper>
 #include <DFontManager>
 #include <DPlatformTheme>
+#include <DPlatformHandle>
 #include <QQmlEngine>
 
 DQUICK_BEGIN_NAMESPACE
@@ -51,4 +52,11 @@ struct DFontManagerForeign
     QML_NAMED_ELEMENT(FontManager)
 };
 
+struct DPlatformHandleForeign
+{
+    Q_GADGET
+    QML_FOREIGN(DPlatformHandle)
+    QML_NAMED_ELEMENT(PlatformHandle)
+};
+
 DQUICK_END_NAMESPACE
